@@ -745,8 +745,8 @@ string CSQL::getError(void *Result) {
     #ifdef USE_ODBC
     case SQLXX_ODBC:
       switch (SQLError((SQLHENV) Env,(SQLHDBC) DB,(SQLHSTMT) Result,
-          (UCHAR *) cSQLState,&iNativeError,(UCHAR *) cErrorMsg,
-          sizeof(cErrorMsg),&iMsgLen)) {
+          (SQLCHAR *) cSQLState, (SQLINTEGER *) &iNativeError,
+          (SQLCHAR *) cErrorMsg, sizeof(cErrorMsg),&iMsgLen)) {
         case SQL_INVALID_HANDLE:
           throw sqlxx_error("SQLError: Invalid handle");
           break;
